@@ -263,7 +263,9 @@ class ScopedVisitor(ast.NodeVisitor):
         else:
             return name
 
-    def _get_alias_name(self, node: ast.alias) -> str:
+    def _get_alias_name(
+        self, node: ast.alias, import_node: ast.ImportFrom | None = None
+    ) -> str:
         """Get the string name of an imported alias.
 
         Mangles the "as" name if it's a local variable.
@@ -281,11 +283,15 @@ class ScopedVisitor(ast.NodeVisitor):
             # Don't mangle - user has no control over package name
             basename = node.name.split(".")[0]
             if basename == "*":
-                line = (
-                    f"line {node.lineno}"
+                # Use the ImportFrom node's line number for consistency
+                line_num = (
+                    import_node.lineno
+                    if import_node and hasattr(import_node, "lineno")
+                    else node.lineno
                     if hasattr(node, "lineno")
-                    else "line ..."
+                    else None
                 )
+                line = f"line {line_num}" if line_num else "line ..."
                 raise ImportStarError(
                     f"{line} SyntaxError: Importing symbols with `import *` "
                     "is not allowed in marimo."
@@ -973,7 +979,7 @@ class ScopedVisitor(ast.NodeVisitor):
         # we don't recurse into the alias nodes, since we define the
         # aliases here
         for alias_node in node.names:
-            variable_name = self._get_alias_name(alias_node)
+            variable_name = self._get_alias_name(alias_node, import_node=node)
             original_name = alias_node.name
             self._define(
                 None,
