@@ -2,15 +2,15 @@
 from __future__ import annotations
 
 import functools
-import json
 from collections import defaultdict
 from collections.abc import Sequence
 from typing import Any, Optional, Union, cast
 
 from marimo._data.models import BinValue, ColumnStats, ExternalDataType
 from marimo._dependencies.dependencies import DependencyManager
+from marimo._messaging.msgspec_encoder import encode_json_str
 from marimo._output.mime import MIME
-from marimo._plugins.core.json_encoder import WebComponentEncoder
+from marimo._output.superjson import SuperJson
 from marimo._plugins.core.web_component import JSONType
 from marimo._plugins.ui._impl.tables.format import (
     FormatMapping,
@@ -100,10 +100,10 @@ class DefaultTableManager(TableManager[JsonTableData]):
     def to_json_str(
         self, format_mapping: Optional[FormatMapping] = None
     ) -> str:
-        return json.dumps(
-            self._normalize_data(self.apply_formatting(format_mapping).data),
-            cls=WebComponentEncoder,
+        normalized = self._normalize_data(
+            self.apply_formatting(format_mapping).data
         )
+        return encode_json_str(SuperJson(normalized))
 
     def to_parquet(self) -> bytes:
         if isinstance(self.data, dict) and not self.is_column_oriented:
