@@ -86,6 +86,7 @@ def get_refactor_or_insert_notebook_cell_system_prompt(
     *,
     language: Language,
     is_insert: bool,
+    support_multiple_cells: bool,
     custom_rules: Optional[str],
     cell_code: Optional[str],
     selected_text: Optional[str],
@@ -94,6 +95,21 @@ def get_refactor_or_insert_notebook_cell_system_prompt(
 ) -> str:
     if cell_code:
         system_prompt = f"Here's a {language} document from a Python notebook that I'm going to ask you to make an edit to.\n\n"
+    elif support_multiple_cells:
+        system_prompt = (
+            "You are an AI assistant integrated into the marimo notebook code editor.\n"
+            "Your goal is to create new cells in the notebook.\n"
+            "You can create multiple cells with different languages. Each cell should be wrapped in backticks.\n"
+            "The user may reference additional context in the form @kind://name. You can use this context to help you with the current task.\n"
+            "You can reference variables from other cells, but you cannot redefine a variable if it already exists.\n"
+            "Immediately start with the following format. Do NOT comment on the code, just output the code itself: \n\n"
+            "```python\n{PYTHON_CODE}\n```\n\n"
+            '```sql\ndf_name = mo.sql(f"""{SQL_QUERY}""")\n```\n\n'
+            '```markdown\nmo.md(f"""{MARKDOWN_CONTENT}""")\n```\n\n'
+            "You can have multiple cells of any type. Each cell is wrapped in backticks with the appropriate language identifier.\n"
+            "Create clear variable names if they will be used in other cells. Do not prefix with underscore.\n"
+            "Separate logic into multiple cells to keep the code organized and readable."
+        )
     else:
         system_prompt = (
             "You are an AI assistant integrated into the marimo notebook code editor.\n"
@@ -147,7 +163,14 @@ def get_refactor_or_insert_notebook_cell_system_prompt(
         system_prompt += "\n\nAnd here's the section to rewrite based on that prompt again for reference:\n\n"
         system_prompt += _tag("rewrite_this", selected_text)
 
-    if language in language_rules and language_rules[language]:
+    if support_multiple_cells:
+        # Add all language rules for multi-cell scenarios
+        for lang in language_rules:
+            if len(language_rules[lang]) > 0:
+                system_prompt += (
+                    f"\n\n## Rules for {lang}:\n{_rules(language_rules[lang])}"
+                )
+    elif language in language_rules and language_rules[language]:
         system_prompt += (
             f"\n\n## Rules for {language}\n{_rules(language_rules[language])}"
         )
@@ -165,7 +188,10 @@ def get_refactor_or_insert_notebook_cell_system_prompt(
             "code_from_other_cells", other_cell_codes
         )
 
-    system_prompt += "\n\nAgain, just output the code itself."
+    if support_multiple_cells:
+        system_prompt += "\n\nAgain, just output code wrapped in cells. Each cell is wrapped in backticks with the appropriate language identifier (python, sql, markdown)."
+    else:
+        system_prompt += "\n\nAgain, just output the code itself."
 
     return system_prompt
 
