@@ -1,16 +1,19 @@
 # Copyright 2024 Marimo. All rights reserved.
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Optional, cast
 
 from starlette.authentication import requires
+from starlette.background import BackgroundTask
+from starlette.responses import JSONResponse
 
 from marimo import _loggers
+from marimo._config.config import PartialMarimoConfig
+from marimo._messaging.msgspec_encoder import asdict
 from marimo._runtime.requests import SetUserConfigRequest
 from marimo._server.api.deps import AppState
 from marimo._server.api.utils import parse_request
 from marimo._server.models.models import (
-    BaseResponse,
     SaveUserConfigurationRequest,
     SuccessResponse,
 )
@@ -31,7 +34,7 @@ router = APIRouter()
 async def save_user_config(
     *,
     request: Request,
-) -> BaseResponse:
+) -> JSONResponse:
     """
     requestBody:
         content:
@@ -51,12 +54,19 @@ async def save_user_config(
     body = await parse_request(
         request, cls=SaveUserConfigurationRequest, allow_unknown_keys=True
     )
-    config = app_state.config_manager.save_config(body.config)
+    # TODO: we may want to validate deep-partial here, but validating with PartialMarimoConfig it too strict
+    # so we just cast to PartialMarimoConfig
+    config = app_state.config_manager.save_config(
+        cast(PartialMarimoConfig, body.config)
+    )
 
+    background_task: Optional[BackgroundTask] = None
     # Update the server's view of the config
     if config["completion"]["copilot"]:
         LOGGER.debug("Starting copilot server")
-        await app_state.session_manager.start_lsp_server()
+        background_task = BackgroundTask(
+            app_state.session_manager.start_lsp_server
+        )
 
     # Update the kernel's view of the config
     # Session could be None if the user is on the home page
@@ -68,4 +78,8 @@ async def save_user_config(
                 app_state.require_current_session_id()
             ),
         )
-    return SuccessResponse()
+
+    return JSONResponse(
+        content=asdict(SuccessResponse()),
+        background=background_task,
+    )
