@@ -13,7 +13,7 @@
 
 import marimo
 
-__generated_with = "0.12.10"
+__generated_with = "0.15.5"
 app = marimo.App(width="medium")
 
 
@@ -200,7 +200,7 @@ def _(has_polars_installed):
         import pandas as pd
 
         df = pd.DataFrame(_data)
-    return (df,)
+    return
 
 
 @app.cell(hide_code=True)
@@ -210,7 +210,7 @@ def _(mo):
 
 
 @app.cell
-def _(df, mo):
+def _(mo):
     _df = mo.sql(
         f"""
         -- This SQL cell is special since we can reference existing dataframes in the global scope as a table in the SQL query. For example, we can reference the `df` dataframe in the global scope, which was defined in another cell using Python.
@@ -245,7 +245,7 @@ def _(mo, string):
 
 
 @app.cell
-def _(df, mo, token_prefix):
+def _(mo, token_prefix):
     result = mo.sql(
         f"""
         -- Change the dropdown to see the SQL query filter itself!
@@ -401,7 +401,7 @@ def _(cars, mo):
 
 
 @app.cell
-def _(cars, cylinders_dropdown, mo, origin_dropdown):
+def _(cylinders_dropdown, mo, origin_dropdown):
     filtered_cars = mo.sql(
         f"""
         SELECT * FROM cars
